@@ -2,7 +2,10 @@
 from dynaconf.base import LazySettings
 from dynaconf.validator import Validator
 from dynaconf.transformator import Transformator
+from dynaconf.contrib import FlaskDynaconf
 
 settings = LazySettings()
 
-__all__ = ['settings', 'LazySettings', 'Validator', 'Transformator']
+__all__ = [
+    'settings', 'LazySettings', 'Validator', 'Transformator', 'FlaskDynaconf'
+]
